==> kadu_3.0~rc1.orig.tar.bz2: kadu-3.0-rc1/plugins/mpd_mediaplayer/translations/mpd_mediaplayer_pt_BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>@default</name>
    <message>
        <source>MediaPlayer</source>
        <translation>MediaPlayer</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Geral</translation>
    </message>
    <message>
        <source>Media Player Daemon Settings</source>
        <translation>Configurações do Media Player Daemon</translation>
    </message>
    <message>
        <source>Host</source>
        <translation>Host</translation>
    </message>
    <message>
        <source>Media Player Daemon server address</source>
        <translation>Endereço do servidor Media Player Daemon</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Porta</translation>
    </message>
    <message>
        <source>Port number MPD is listening on</source>
        <translation>Número da porta que o MPD está escutando</translation>
    </message>
    <message>
        <source>Connection timeout (seconds)</source>
        <translation>Timeout de conexão (segundos)</translation>
    </message>
    <message>
        <source>Number of seconds before the connection is terminated</source>
        <translation>Número de segundos antes de a conexão ser encerrada</translation>
    </message>
</context>
<context>
    <name>MPDMediaPlayer</name>
    <message>
        <source>Unknown</source>
        <translation>Desconhecido</translation>
    </message>
</context>
</TS>

==> kadu_4.1.orig.tar.bz2: kadu-4.1/plugins/mpd_mediaplayer/translations/mpd_mediaplayer_pt_BR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_BR" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>MediaPlayer</source>
        <translation>MediaPlayer</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Geral</translation>
    </message>
    <message>
        <source>Media Player Daemon Settings</source>
        <translation>Configurações do Media Player Daemon</translation>
    </message>
    <message>
        <source>Host</source>
        <translation>Host</translation>
    </message>
    <message>
        <source>Media Player Daemon server address</source>
        <translation>Endereço do servidor Media Player Daemon</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Porta</translation>
    </message>
    <message>
        <source>Port number MPD is listening on</source>
        <translation>Número da porta que o MPD está escutando</translation>
    </message>
    <message>
        <source>Connection timeout (seconds)</source>
        <translation>Timeout de conexão (segundos)</translation>
    </message>
    <message>
        <source>Number of seconds before the connection is terminated</source>
        <translation>Número de segundos antes de a conexão ser encerrada</translation>
    </message>
</context>
<context>
    <name>MPDMediaPlayer</name>
    <message>
        <source>Unknown</source>
        <translation>Desconhecido</translation>
    </message>
</context>
</TS>
